spacepy.toolbox.normalize — SpacePy v0.1.5 Manual

### Navigation

- index
- modules |
- modules |
- next |
- previous |
- homepage|
- search|
- documentation »
- toolbox - Toolbox of various functions and generic utilities »

# spacepy.toolbox.normalize

`spacepy.toolbox.` `normalize`(vec)

  Given an input vector normalize the vector

  Parameters: | vec : array_like input vector to normalize
  Returns: | out : array_like normalized vector

  Examples

      >>> import spacepy.toolbox as tb
      >>> tb.normalize([1,2,3])
      [0.0, 0.5, 1.0]

### Navigation

- index
- modules |
- modules |
- next |
- previous |
- homepage|
- search|
- documentation »
- toolbox - Toolbox of various functions and generic utilities »